0.5.1 (2026-02-05)
------------------

- Fix examples (supply ``location`` attribute) in TETE frame schema. [#80]

0.5.0 (2026-02-03)
------------------

- Drop Python 3.9 support [#77]
- Add TETE and TEME coordinate frames. [#78]

0.4.0 (2025-05-27)
------------------

- Changes documentation configuration settings to make this consistent with other asdf-related projects [#61]
- Fix typo in latex logo path [#62]
- Adds global navigation in docs top bar [#63]
- Update schemas to prefer tag over ref [#64]

0.3.0 (2024-03-09)
------------------

- Add ``asdf-astropy`` as a test dependency. [#34]
- Drop official support for Python 3.8 [#42]
- Update schemas for ASDF standard 1.6.0 [#55]

0.2.0 (2023-03-21)
------------------

- Add documentation to package. [#8]
- Update asdf version and require python 3.8. [#14]
- Switch to pyproject.toml. [#15]

0.1.0 (2021-12-04)
------------------

- Initial release.
